import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faArrowLeft, faArrowRight } from '@fortawesome/free-solid-svg-icons';
import '@fortawesome/fontawesome-svg-core/styles.css'; // Import FontAwesome styles
import './IconSelect.css'; // Import CSS for styling

const IconsPerPage = 20;

const IconSelect = ({ icons, onIconClick }) => {
  const [currentPage, setCurrentPage] = useState(1);
  const totalPages = Math.ceil(icons.length / IconsPerPage);

  const handlePageChange = (direction) => {
    setCurrentPage((prevPage) => Math.max(1, Math.min(totalPages, prevPage + direction)));
  };

  const startIdx = (currentPage - 1) * IconsPerPage;
  const endIdx = startIdx + IconsPerPage;
  const iconsToDisplay = icons.slice(startIdx, endIdx);

  return (
    <div className="icon-select">
      <div className="icon-grid">
        {iconsToDisplay.map((icon, index) => (
          <div key={index} className="icon-item" onClick={() => onIconClick(icon)}>
            <FontAwesomeIcon icon={icon} />
          </div>
        ))}
      </div>
      <div className="pagination">
        <button onClick={() => handlePageChange(-1)} disabled={currentPage === 1}>
          <FontAwesomeIcon icon={faArrowLeft} />
        </button>
        <span>Page {currentPage} of {totalPages}</span>
        <button onClick={() => handlePageChange(1)} disabled={currentPage === totalPages}>
          <FontAwesomeIcon icon={faArrowRight} />
        </button>
      </div>
    </div>
  );
};

IconSelect.propTypes = {
  icons: PropTypes.arrayOf(PropTypes.string).isRequired,
  onIconClick: PropTypes.func.isRequired,
};

export default IconSelect;
